@@ -32,15 +32,7 @@ hergm.wrapper <- function(seed, hergm_list)
     as.integer(hergm_list$structural),
     as.integer(hergm_list$min_size),
     as.integer(hergm_list$max_number),
-    as.integer(hergm_list$null$alpha_shape),
-    as.integer(hergm_list$null$alpha_rate),
     as.integer(hergm_list$null$alpha),
-    as.integer(hergm_list$null$eta_mean_mean),
-    as.integer(hergm_list$null$eta_mean_precision),
-    as.integer(hergm_list$null$eta_precision_shape),
-    as.integer(hergm_list$null$eta_precision_rate),
-    as.integer(hergm_list$null$eta_mean),
-    as.integer(hergm_list$null$eta_precision),
     as.integer(hergm_list$null$eta),
     as.integer(hergm_list$null$indicator),
     as.double(hergm_list$alpha),
