@@ -189,15 +189,7 @@ void Simulation(int *dyaddependence,
              int *structural,
              int *min_size,
              int *max_number,
-             int *null_alpha_shape,
-             int *null_alpha_rate,
              int *null_alpha,
-             int *null_eta_mean_mean,
-             int *null_eta_mean_precision,
-             int *null_eta_precision_shape,
-             int *null_eta_precision_rate,
-             int *null_eta_mean,
-             int *null_eta_precision,
              int *null_eta,
              int *null_indicator,
              double *alpha,
